nlptools
========

.. autofunction:: txttk.nlptools.sent_tokenize
.. autofunction:: txttk.nlptools.sent_count
.. autofunction:: txttk.nlptools.clause_tokenize
.. autofunction:: txttk.nlptools.word_tokenize
.. autofunction:: txttk.nlptools.slim_stem
.. autofunction:: txttk.nlptools.powerset
.. autofunction:: txttk.nlptools.ngram
.. autofunction:: txttk.nlptools.power_ngram

